@@ -482,8 +482,7 @@ client_set_restart_command (GnomeClient *client)
   vals[i].length = strlen (sm_screen);
   vals[i++].value = (char *)sm_screen;
   vals[i].length = strlen (tmp);
-  vals[i++].value = g_strdup(tmp);
-  g_free(tmp);
+  vals[i++].value = tmp;
 #endif
 
   for (list = client->static_args; list; list = g_list_next (list))
@@ -501,6 +500,10 @@ client_set_restart_command (GnomeClient *client)
   client_set_value (client, SmRestartCommand, SmLISTofARRAY8, i, vals);
 
   g_free (vals);
+
+#ifdef HAVE_GTK_MULTIHEAD
+  g_free (tmp);
+#endif
 }
 
 static void
@@ -1140,7 +1143,7 @@ master_client_disconnect (GnomeClient *client,
 }
 
 /**
- * gnome_master_client
+ * gnome_master_client:
  *
  * Description:
  * Get the master session management client.  This master client gets a client
@@ -1363,7 +1366,7 @@ gnome_real_client_finalize (GObject *object)
 
 
 /**
- * gnome_client_new
+ * gnome_client_new:
  *
  * Description: Allocates memory for a new GNOME session management client
  * object. After allocating, the client tries to connect to a session manager.
@@ -1386,7 +1389,7 @@ gnome_client_new (void)
 
 
 /**
- * gnome_client_new_without_connection
+ * gnome_client_new_without_connection:
  *
  * Description: Allocates memory for a new GNOME session management client
  * object. You probably want to use gnome_master_client() instead.
@@ -1418,7 +1421,7 @@ gnome_client_new_without_connection (void)
 
 
 /**
- * gnome_client_flush
+ * gnome_client_flush:
  * @client: A #GnomeClient instance.
  *
  * Description:
@@ -1447,7 +1450,7 @@ gnome_client_flush (GnomeClient *client)
 
 
 /**
- * gnome_client_connect
+ * gnome_client_connect:
  * @client: A #GnomeClient instance.
  *
  * Description: Causes the client to connect to the session manager.
@@ -1523,7 +1526,7 @@ gnome_client_connect (GnomeClient *client)
 
 
 /**
- * gnome_client_disconnect
+ * gnome_client_disconnect:
  * @client: A #GnomeClient instance.
  *
  * Description: Disconnect the client from the session manager.
@@ -1584,7 +1587,7 @@ gnome_client_get_flags (GnomeClient *client)
 /*****************************************************************************/
 
 /**
- * gnome_client_set_clone_command
+ * gnome_client_set_clone_command:
  * @client: Pointer to GNOME session client object.
  * @argc: Number of strings in the @argv vector.
  * @argv: Argument strings, suitable for use with execv().
@@ -1610,7 +1613,7 @@ gnome_client_set_clone_command (GnomeClient *client,
 }
 
 /**
- * gnome_client_set_current_directory
+ * gnome_client_set_current_directory:
  * @client: Pointer to GNOME session client object.
  * @dir: Directory path.
  *
@@ -1645,14 +1648,7 @@ gnome_client_set_current_directory (GnomeClient *client,
 }
 
 
-
-/**
- * gnome_client_set_discard_command
- * @client: Pointer to GNOME session client object.
- * @argc: Number of strings in argv.
- * @argv: Vector of strings such as those passed to execv().
- *
- **/
+/* See doc/reference/tmpl/gnome-client.sgml for documentation. */
 
 void
 gnome_client_set_discard_command (GnomeClient *client,
@@ -1686,7 +1682,7 @@ gnome_client_set_discard_command (GnomeClient *client,
 
 
 /**
- * gnome_client_set_environment
+ * gnome_client_set_environment:
  * @client: Pointer to GNOME session client object.
  * @name: Name of the environment variable
  * @value: Value of the environment variable
@@ -1740,7 +1736,7 @@ gnome_client_set_environment (GnomeClient *client,
 
 
 /**
- * gnome_client_set_process_id
+ * gnome_client_set_process_id:
  * @client: Pointer to GNOME session client object.
  * @pid: PID to set as the client's PID.
  *
@@ -1769,7 +1765,7 @@ gnome_client_set_process_id (GnomeClient *client, pid_t pid)
 
 
 /**
- * gnome_client_set_program
+ * gnome_client_set_program:
  * @client: Pointer to GNOME session client object.
  * @program: Name of the program.
  *
@@ -1801,7 +1797,7 @@ gnome_client_set_program (GnomeClient *client,
 
 
 /**
- * gnome_client_set_resign_command
+ * gnome_client_set_resign_command:
  * @client: Pointer to GNOME session client object.
  * @argc: Number of strings in @argv.
  * @argv: execv()-style command to undo the effects of the client.
@@ -1849,7 +1845,7 @@ gnome_client_set_resign_command (GnomeClient *client,
 
 
 /**
- * gnome_client_set_restart_command
+ * gnome_client_set_restart_command:
  * @client: Pointer to GNOME session client object.
  * @argc: Number of strings in argv.
  * @argv: Argument vector to an execv() to restart the client.
@@ -1882,7 +1878,7 @@ gnome_client_set_restart_command (GnomeClient *client,
 }
 
 /**
- * gnome_client_set_priority
+ * gnome_client_set_priority:
  * @client: Pointer to GNOME session client object.
  * @priority: Position of client in session start up ordering.
  *
@@ -1911,7 +1907,7 @@ gnome_client_set_priority (GnomeClient *client, guint priority)
 }
 
 /**
- * gnome_client_set_restart_style
+ * gnome_client_set_restart_style:
  * @client: Pointer to GNOME session client object.
  * @style: When to restart the client.
  *
@@ -1963,7 +1959,7 @@ gnome_client_set_restart_style (GnomeClient *client,
 
 
 /**
- * gnome_client_set_shutdown_command
+ * gnome_client_set_shutdown_command:
  * @client: Pointer to GNOME session client object.
  * @argc: Number of strings in argv.
  * @argv: Command to shutdown the client if the client isn't running.
@@ -2010,7 +2006,7 @@ gnome_client_set_shutdown_command (GnomeClient *client,
 
 
 /**
- * gnome_client_set_user_id
+ * gnome_client_set_user_id:
  * @client: Pointer to GNOME session client object.
  * @id: Username.
  *
@@ -2039,7 +2035,7 @@ gnome_client_set_user_id (GnomeClient *client,
 
 
 /**
- * gnome_client_add_static_arg
+ * gnome_client_add_static_arg:
  * @client: Pointer to GNOME session client object.
  * @...: %NULL-terminated list of arguments to add to the restart command.
  *
@@ -2074,7 +2070,7 @@ gnome_client_add_static_arg (GnomeClient *client, ...)
 
 
 /**
- * gnome_client_set_id
+ * gnome_client_set_id:
  * @client: A #GnomeClient instance.
  * @id: Session management ID.
  *
@@ -2099,12 +2095,12 @@ gnome_client_set_id (GnomeClient *client, const gchar *id)
 
 
 /**
- * gnome_client_get_id
+ * gnome_client_get_id:
  * @client: A #GnomeClient instance.
  *
  * Description: Returns session management ID
  *
- * Returns:  Session management ID for this client; %NULL if not connected to a
+ * Returns: Session management ID for this client; %NULL if not connected to a
  * session manager.
  **/
 
@@ -2118,7 +2114,7 @@ gnome_client_get_id (GnomeClient *client)
 }
 
 /**
- * gnome_client_get_previous_id
+ * gnome_client_get_previous_id:
  * @client: A #GnomeClient instance.
  *
  * Description: Get the session management ID from the previous session.
@@ -2157,7 +2153,7 @@ gnome_client_get_desktop_id (GnomeClient *client)
 }
 
 /**
- * gnome_client_get_config_prefix
+ * gnome_client_get_config_prefix:
  * @client: Pointer to GNOME session client object.
  *
  * Description: Get the config prefix for a client. This config prefix
@@ -2191,7 +2187,7 @@ gnome_client_get_config_prefix (GnomeClient *client)
 static gchar* config_prefix = NULL;
 
 /**
- * gnome_client_set_global_config_prefix
+ * gnome_client_set_global_config_prefix:
  * @client: Pointer to GNOME session client object.
  * @prefix: Prefix for saving the global configuration.
  *
@@ -2224,7 +2220,7 @@ gnome_client_set_global_config_prefix (GnomeClient *client, const gchar* prefix)
 }
 
 /**
- * gnome_client_get_global_config_prefix
+ * gnome_client_get_global_config_prefix:
  * @client: Pointer to GNOME session client object.
  *
  * Description: Get the config prefix that will be returned by
@@ -2238,7 +2234,7 @@ gnome_client_set_global_config_prefix (GnomeClient *client, const gchar* prefix)
  * practice limits the users freedom to configure each instance in a different
  * way so it should be used with caution.
  *
- * Returns:  The config prefix as a newly allocated string.
+ * Returns: The config prefix as a newly allocated string.
  **/
 
 const gchar *
@@ -2488,7 +2484,7 @@ gnome_client_save_dialog_show (GnomeClient *client, gint key,
 }
 
 /**
- * gnome_client_save_any_dialog
+ * gnome_client_save_any_dialog:
  * @client: Pointer to #GnomeClient object.
  * @dialog: Pointer to GNOME dialog widget (a #GtkDialog widget).
  *
@@ -2515,7 +2511,7 @@ gnome_client_save_any_dialog (GnomeClient *client, GtkDialog *dialog)
 }
 
 /**
- * gnome_client_save_error_dialog
+ * gnome_client_save_error_dialog:
  * @client: Pointer to #GnomeClient object.
  * @dialog: Pointer to GNOME dialog widget (a #GtkDialog widget).
  *
@@ -2543,7 +2539,7 @@ gnome_client_save_error_dialog (GnomeClient *client, GtkDialog *dialog)
 }
 
 /**
- * gnome_client_request_interaction
+ * gnome_client_request_interaction:
  * @client: A #GnomeClient object.
  * @dialog_type: The type of dialog to create.
  * @function: Callback to invoke to perform the interaction.
@@ -2585,7 +2581,7 @@ gnome_client_request_interaction (GnomeClient *client,
 
 
 /**
- * gnome_client_request_interaction_interp
+ * gnome_client_request_interaction_interp:
  * @client: Pointer to GNOME session client object.
  * @dialog_type: Type of dialog to show.
  * @function: Callback to perform the interaction (a #GnomeInteractFunction).
@@ -2624,7 +2620,7 @@ gnome_client_request_interaction_interp (GnomeClient *client,
 
 
 /**
- * gnome_client_request_phase_2
+ * gnome_client_request_phase_2:
  * @client: A #GnomeClient object.
  *
  * Description:  Request the session managaer to emit the "save_yourself"
@@ -2648,7 +2644,7 @@ gnome_client_request_phase_2 (GnomeClient *client)
 
 
 /**
- * gnome_client_request_save
+ * gnome_client_request_save:
  * @client: Pointer to GNOME session client object.
  * @save_style: Save style to request.
  * @shutdown: Whether to log out of the session.
@@ -2766,7 +2762,7 @@ gnome_client_request_save (GnomeClient	       *client,
 
 
 /**
- * gnome_interaction_key_return
+ * gnome_interaction_key_return:
  * @key: Key passed to interaction callback
  * @cancel_shutdown: If %TRUE, cancel the shutdown
  *
