@@ -153,11 +153,11 @@ struct _GnomeClient
   /* other internal state information */
   GnomeClientState    state : 3;
 
-  gboolean            shutdown : 1;
-  gboolean            fast : 1;
-  gboolean            save_phase_2_requested : 1;
-  gboolean            save_successfull : 1;
-  gboolean            save_yourself_emitted : 1;
+  guint               shutdown : 1;
+  guint               fast : 1;
+  guint               save_phase_2_requested : 1;
+  guint               save_successfull : 1;
+  guint               save_yourself_emitted : 1;
 
   gpointer            reserved; /* Reserved for private struct */
 };
@@ -170,16 +170,20 @@ struct _GnomeClientClass
   gboolean (* save_yourself)  (GnomeClient        *client,
 			       gint                phase,
 			       GnomeSaveStyle      save_style,
-			       gint                shutdown,
+			       gboolean                shutdown,
 			       GnomeInteractStyle  interact_style,
-			       gint                fast);
+			       gboolean                fast);
   void (* die)                (GnomeClient        *client);
   void (* save_complete)      (GnomeClient        *client);
   void (* shutdown_cancelled) (GnomeClient        *client);
 
   void (* connect)            (GnomeClient        *client,
-			       gint                restarted);
+			       gboolean            restarted);
   void (* disconnect)         (GnomeClient        *client);
+
+  /* Padding for possible expansion */
+  gpointer padding1;
+  gpointer padding2;
 };
 
 #define GNOME_CLIENT_MODULE gnome_client_module_info_get()
@@ -336,7 +340,7 @@ void         gnome_client_set_process_id         (GnomeClient *client,
 void         gnome_client_set_program            (GnomeClient *client, 
 						  const gchar *program);
 void         gnome_client_set_user_id            (GnomeClient *client,
-						  const gchar *user_id);
+						  const gchar *id);
 
 /* The following function may be called during a "save_youself" handler
    to request that a (modal) dialog is presented to the user. The session 
@@ -406,7 +410,7 @@ GnomeClient *gnome_client_new_without_connection (void);
 
 /* Try to connect to a session manager.  If the client was created
    with a valid session management client id, we will try to connect
-   to the manager with this old id.  If the connection was successfull,
+   to the manager with this old id.  If the connection was successful,
    the "connect" signal will be emitted, after some default properties
    have been sent to the session manager.  */
 void         gnome_client_connect                (GnomeClient *client);
@@ -418,7 +422,7 @@ void         gnome_client_disconnect             (GnomeClient *client);
 /* Set the client id.  This is only possible, if the client is not
    connected to a session manager.  */
 void         gnome_client_set_id                 (GnomeClient *client,
-						  const gchar *client_id);
+						  const gchar *id);
 
 /* Get the client id of a session management client object.  If this
    object has never been connected to a session manager and a client
@@ -430,6 +434,12 @@ const gchar*       gnome_client_get_id                 (GnomeClient *client);
    manager tries to maintain the same id from one session to another. */
 const gchar*       gnome_client_get_previous_id        (GnomeClient *client);
 
+/* Get the client ID of the desktop's current instance, i.e.  if you
+ * consider the desktop as a whole as a session managed app, this
+ * returns its session ID (GNOME extension to SM)
+ */
+const gchar*       gnome_client_get_desktop_id   (GnomeClient *client);
+
 /* Use the following functions, if you want to interact with the user
    during a "save_yourself" handler without being restricted to using 
    the dialog based commands gnome_client_save_[any/error]_dialog.  
@@ -439,13 +449,13 @@ const gchar*       gnome_client_get_previous_id        (GnomeClient *client);
    clients from interacting until this key is returned with 
    'gnome_interaction_key_return'.  */
 void         gnome_client_request_interaction    (GnomeClient *client,
-						  GnomeDialogType dialog,
-						  GnomeInteractFunction func,
-						  gpointer client_data);
+						  GnomeDialogType dialog_type,
+						  GnomeInteractFunction function,
+						  gpointer data);
 
 void         gnome_client_request_interaction_interp (GnomeClient *client,
-						      GnomeDialogType dialog,
-						      GtkCallbackMarshal func,
+						      GnomeDialogType dialog_type,
+						      GtkCallbackMarshal function,
 						      gpointer data,
 						      GtkDestroyNotify destroy);
 
